@@ -1,9 +1,9 @@
-import { awscdk, Gitpod, DevEnvironmentDockerImage, ReleasableCommits } from 'projen';
+import { awscdk } from 'projen';
 import { NpmAccess } from 'projen/lib/javascript';
 import { WorkflowNoDockerPatch } from './projenrc/workflow-no-docker-patch';
 
 // the version of k8s this branch supports
-const SPEC_VERSION = '21';
+const SPEC_VERSION = '24';
 const releaseWorkflowName = `release-kubectl-v${SPEC_VERSION}`;
 const defaultReleaseBranchName = `kubectl-v${SPEC_VERSION}/main`;
 
@@ -11,7 +11,7 @@ const project = new awscdk.AwsCdkConstructLibrary({
   projenrcTs: true,
   author: 'Amazon Web Services',
   authorAddress: 'aws-cdk-dev@amazon.com',
-  cdkVersion: '2.28.0',
+  cdkVersion: '2.0.0',
   name: `@aws-cdk/lambda-layer-kubectl-v${SPEC_VERSION}`,
   description: `A Lambda Layer that contains kubectl v1.${SPEC_VERSION}`,
   repositoryUrl: 'https://github.com/cdklabs/awscdk-asset-kubectl.git',
@@ -25,9 +25,6 @@ const project = new awscdk.AwsCdkConstructLibrary({
   npmAccess: NpmAccess.PUBLIC,
   releaseTagPrefix: `kubectl-v${SPEC_VERSION}`,
   releaseWorkflowName: releaseWorkflowName,
-  // If we don't do this we release the devDependency updates that happen every day, which blows out
-  // our PyPI storage budget even though there aren't any functional changes.
-  releasableCommits: ReleasableCommits.featuresAndFixes(),
   defaultReleaseBranch: defaultReleaseBranchName,
   publishToPypi: {
     distName: `aws-cdk.lambda-layer-kubectl-v${SPEC_VERSION}`,
@@ -62,7 +59,6 @@ const project = new awscdk.AwsCdkConstructLibrary({
         actions: {
           backport: {
             regexes: [`kubectl-v(?!20|${SPEC_VERSION})[\\d]*\\/main`],
-            labels: ['auto-approve'],
           },
         },
       }],
@@ -76,14 +72,4 @@ new WorkflowNoDockerPatch(project, { workflow: 'release', workflowName: `release
 
 project.preCompileTask.exec('layer/build.sh');
 
-// For gitpod users, use jsii/superchain as the dockerImage for the workspace.
-const gitpod = new Gitpod(project, {
-  dockerImage: DevEnvironmentDockerImage.fromImage('public.ecr.aws/jsii/superchain:1-buster-slim-node18'),
-});
-
-gitpod.addVscodeExtensions(
-  'dbaeumer.vscode-eslint',
-  'AmazonWebServices.aws-toolkit-vscode',
-);
-
 project.synth();
