@@ -44,26 +44,24 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class KubectlV24Layer(
-    aws_cdk.aws_lambda.LayerVersion,
+    _aws_cdk_aws_lambda_ceddda9d.LayerVersion,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/lambda-layer-kubectl-v24.KubectlV24Layer",
 ):
     '''A CDK Asset construct that contains ``kubectl`` and ``helm``.'''
 
-    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            def stub(scope: constructs.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a02f7c194114c3c9835731097587369e5f7bbe7b523842b61050f2111404007c)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -74,3 +72,10 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__a02f7c194114c3c9835731097587369e5f7bbe7b523842b61050f2111404007c(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
